pub struct AbilitySlotsLevel {
pub from_chapter_level: i64,
pub ability_slots: u64,
}Fields
from_chapter_level: i64ability_slots: u64Trait Implementations
Sourceimpl Clone for AbilitySlotsLevel
impl Clone for AbilitySlotsLevel
Sourcefn clone(&self) -> AbilitySlotsLevel
fn clone(&self) -> AbilitySlotsLevel
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AbilitySlotsLevel
impl Debug for AbilitySlotsLevel
Sourceimpl<'de> Deserialize<'de> for AbilitySlotsLevel
impl<'de> Deserialize<'de> for AbilitySlotsLevel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AbilitySlotsLevel
impl JsonSchema for AbilitySlotsLevel
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AbilitySlotsLevel
impl PartialEq for AbilitySlotsLevel
Sourceimpl Serialize for AbilitySlotsLevel
impl Serialize for AbilitySlotsLevel
Sourceimpl Tsify for AbilitySlotsLevel
impl Tsify for AbilitySlotsLevel
const DECL: &'static str = "export interface AbilitySlotsLevel {\n from_chapter_level: number;\n ability_slots: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for AbilitySlotsLevel
impl StructuralPartialEq for AbilitySlotsLevel