pub struct Chapter {
pub id: Uuid,
pub level: i64,
pub fight_ids: Vec<FightTemplateId>,
pub title: I18nString,
}Fields
id: Uuidlevel: i64fight_ids: Vec<FightTemplateId>title: I18nStringTrait Implementations
Sourceimpl CustomType for Chapter
impl CustomType for Chapter
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for Chapter
impl<'de> Deserialize<'de> for Chapter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Chapter
impl JsonSchema for Chapter
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for Chapter
impl Tsify for Chapter
const DECL: &'static str = "export interface Chapter {\n id: Uuid;\n level: number;\n fight_ids: FightTemplateId[];\n title: I18nString;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for Chapter
impl StructuralPartialEq for Chapter