pub struct EnemyReward {
pub currency_id: CurrencyId,
pub from: i64,
pub to: i64,
pub drop_chance: f64,
}Fields
currency_id: CurrencyIdfrom: i64to: i64drop_chance: f64Trait Implementations
Sourceimpl Clone for EnemyReward
impl Clone for EnemyReward
Sourcefn clone(&self) -> EnemyReward
fn clone(&self) -> EnemyReward
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for EnemyReward
impl CustomType for EnemyReward
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for EnemyReward
impl Debug for EnemyReward
Sourceimpl<'de> Deserialize<'de> for EnemyReward
impl<'de> Deserialize<'de> for EnemyReward
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EnemyReward
impl JsonSchema for EnemyReward
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EnemyReward
impl PartialEq for EnemyReward
Sourceimpl Serialize for EnemyReward
impl Serialize for EnemyReward
Sourceimpl Tsify for EnemyReward
impl Tsify for EnemyReward
const DECL: &'static str = "export interface EnemyReward {\n currency_id: CurrencyId;\n from: number;\n to: number;\n drop_chance: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for EnemyReward