pub struct EntityAttribute {
pub attribute_id: AttributeId,
pub value: u64,
}Fields
attribute_id: AttributeIdvalue: u64Trait Implementations
Sourceimpl Clone for EntityAttribute
impl Clone for EntityAttribute
Sourcefn clone(&self) -> EntityAttribute
fn clone(&self) -> EntityAttribute
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for EntityAttribute
impl CustomType for EntityAttribute
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for EntityAttribute
impl Debug for EntityAttribute
Sourceimpl<'de> Deserialize<'de> for EntityAttribute
impl<'de> Deserialize<'de> for EntityAttribute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EntityAttribute
impl JsonSchema for EntityAttribute
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EntityAttribute
impl PartialEq for EntityAttribute
Sourceimpl Serialize for EntityAttribute
impl Serialize for EntityAttribute
Sourceimpl Tsify for EntityAttribute
impl Tsify for EntityAttribute
const DECL: &'static str = "export interface EntityAttribute {\n attribute_id: AttributeId;\n value: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for EntityAttribute
impl StructuralPartialEq for EntityAttribute