pub struct EntityTemplate {
pub id: EntityTemplateId,
pub name: String,
pub spine: String,
pub spine_skin_path: String,
pub spine_scale: u64,
pub cast_time: u64,
pub attributes: Vec<EntityAttribute>,
pub ability_ids: Vec<AbilityId>,
pub width: i8,
pub rewards: Vec<EnemyReward>,
}Fields
id: EntityTemplateIdname: Stringspine: Stringspine_skin_path: Stringspine_scale: u64cast_time: u64attributes: Vec<EntityAttribute>ability_ids: Vec<AbilityId>width: i8rewards: Vec<EnemyReward>Trait Implementations
Sourceimpl Clone for EntityTemplate
impl Clone for EntityTemplate
Sourcefn clone(&self) -> EntityTemplate
fn clone(&self) -> EntityTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for EntityTemplate
impl CustomType for EntityTemplate
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for EntityTemplate
impl Debug for EntityTemplate
Sourceimpl<'de> Deserialize<'de> for EntityTemplate
impl<'de> Deserialize<'de> for EntityTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EntityTemplate
impl JsonSchema for EntityTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EntityTemplate
impl PartialEq for EntityTemplate
Sourceimpl Serialize for EntityTemplate
impl Serialize for EntityTemplate
Sourceimpl Tsify for EntityTemplate
impl Tsify for EntityTemplate
const DECL: &'static str = "export interface EntityTemplate {\n id: EntityTemplateId;\n name: string;\n spine: string;\n spine_skin_path: string;\n spine_scale: number;\n cast_time: number;\n attributes: EntityAttribute[];\n ability_ids: AbilityId[];\n width: number;\n rewards: EnemyReward[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for EntityTemplate
impl StructuralPartialEq for EntityTemplate