pub struct PetSlotsLevel {
pub from_chapter_level: i64,
pub pet_slots: u64,
}Fields
from_chapter_level: i64pet_slots: u64Trait Implementations
Sourceimpl Clone for PetSlotsLevel
impl Clone for PetSlotsLevel
Sourcefn clone(&self) -> PetSlotsLevel
fn clone(&self) -> PetSlotsLevel
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PetSlotsLevel
impl Debug for PetSlotsLevel
Sourceimpl<'de> Deserialize<'de> for PetSlotsLevel
impl<'de> Deserialize<'de> for PetSlotsLevel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PetSlotsLevel
impl JsonSchema for PetSlotsLevel
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PetSlotsLevel
impl PartialEq for PetSlotsLevel
Sourceimpl Serialize for PetSlotsLevel
impl Serialize for PetSlotsLevel
Sourceimpl Tsify for PetSlotsLevel
impl Tsify for PetSlotsLevel
const DECL: &'static str = "export interface PetSlotsLevel {\n from_chapter_level: number;\n pet_slots: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for PetSlotsLevel
impl StructuralPartialEq for PetSlotsLevel